@@ -24,8 +24,7 @@ from Iuppiter.DjangoUtil import (extendInstalledApps,
                                  extendMiddlewareClasses, 
                                  extendTemplateContextProcessors,
                                  extendTemplateDirs, 
-                                 extendDatabaseDefaults, 
-                                 extendAuthenticationBackend)
+                                 extendDatabaseDefaults,)
 
 from oscar import get_core_apps
 from oscar import OSCAR_MAIN_TEMPLATE_DIR
@@ -128,5 +127,12 @@ def attachSettings(settingsDict, enablePaypal=False):
     # Oscar default currency
     OSCAR_DEFAULT_CURRENCY = 'USD'
     #=========================================================================
+    ADDING_AUTHENTICATION_BACKENDS = (
+        'django.contrib.auth.backends.ModelBackend',
+        'oscar.apps.customer.auth_backends.EmailBackend',
+    )
+    update(settingsDict, ADDING_AUTHENTICATION_BACKENDS)
+    #=========================================================================
     if enablePaypal:
         pass
+
